
Translation Table
=================

On this page you can find the list of all ReaScript API functions with their ``reapy`` counterparts (when they exist).

Categories are based on Mespotine's `ReaScript documentation <https://mespotin.uber.space/Mespotine/Ultraschall/Reaper_Api_Documentation.html>`_.

.. contents:: Categories
    :local:
    :depth: 2


API Helper Functions
--------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`APIExists <https://www.reaper.fm/sdk/reascript/reascripthelp.html#APIExists>`_",""
	"`APITest <https://www.reaper.fm/sdk/reascript/reascripthelp.html#APITest>`_","`test_api <reapy.core.reaper.html#reapy.core.reaper.reaper.test_api>`_"
	"`AddRemoveReaScript <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddRemoveReaScript>`_","`add_reascript <reapy.core.reaper.html#reapy.core.reaper.reaper.add_reascript>`_; `remove_reascript <reapy.core.reaper.html#reapy.core.reaper.reaper.remove_reascript>`_"
	"`ClearConsole <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ClearConsole>`_","`clear_console <reapy.core.reaper.html#reapy.core.reaper.reaper.clear_console>`_"
	"`ClearPeakCache <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ClearPeakCache>`_","`clear_peak_cache <reapy.core.reaper.html#reapy.core.reaper.reaper.clear_peak_cache>`_"
	"`ColorFromNative <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ColorFromNative>`_","`rgb_from_native <reapy.core.reaper.html#reapy.core.reaper.reaper.rgb_from_native>`_"
	"`ColorToNative <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ColorToNative>`_","`rgb_to_native <reapy.core.reaper.html#reapy.core.reaper.reaper.rgb_to_native>`_"
	"`DB2SLIDER <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DB2SLIDER>`_","`dB_to_slider <reapy.core.reaper.html#reapy.core.reaper.reaper.dB_to_slider>`_"
	"`ExecProcess <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ExecProcess>`_",""
	"`GetAppVersion <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAppVersion>`_","`get_reaper_version <reapy.core.reaper.html#reapy.core.reaper.reaper.get_reaper_version>`_"
	"`GetExePath <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetExePath>`_","`get_exe_dir <reapy.core.reaper.html#reapy.core.reaper.reaper.get_exe_dir>`_"
	"`GetOS <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetOS>`_",""
	"`GetResourcePath <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetResourcePath>`_","`get_resource_path <reapy.core.reaper.html#reapy.core.reaper.reaper.get_resource_path>`_"
	"`GetToggleCommandState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetToggleCommandState>`_",""
	"`GetToggleCommandStateEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetToggleCommandStateEx>`_",""
	"`IsMediaExtension <https://www.reaper.fm/sdk/reascript/reascripthelp.html#IsMediaExtension>`_",""
	"`Main_OnCommand <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Main_OnCommand>`_","`perform_action <reapy.core.reaper.html#reapy.core.reaper.reaper.perform_action>`_"
	"`Main_OnCommandEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Main_OnCommandEx>`_","`Project.perform_action <reapy.core.html#reapy.core.Project.perform_action>`_"
	"`NamedCommandLookup <https://www.reaper.fm/sdk/reascript/reascripthelp.html#NamedCommandLookup>`_","`get_command_id <reapy.core.reaper.html#reapy.core.reaper.reaper.get_command_id>`_"
	"`ReaScriptError <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ReaScriptError>`_",""
	"`RecursiveCreateDirectory <https://www.reaper.fm/sdk/reascript/reascripthelp.html#RecursiveCreateDirectory>`_","`os.makedirs <reapy.core.reaper.html#reapy.core.reaper.os.makedirs>`_"
	"`ReverseNamedCommandLookup <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ReverseNamedCommandLookup>`_","`get_command_name <reapy.core.reaper.html#reapy.core.reaper.reaper.get_command_name>`_"
	"`SLIDER2DB <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SLIDER2DB>`_","`slider_to_dB <reapy.core.reaper.html#reapy.core.reaper.reaper.slider_to_dB>`_"
	"`SetToggleCommandState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetToggleCommandState>`_",""
	"`ShowActionList <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ShowActionList>`_",""
	"`ShowConsoleMsg <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ShowConsoleMsg>`_","`print <reapy.core.reaper.html#reapy.core.reaper.reaper.print>`_; `show_console_message <reapy.core.reaper.html#reapy.core.reaper.reaper.show_console_message>`_; `reaprint <reapy.core.reaper.html#reapy.core.reaper.reaper.reaprint>`_"
	"`ToggleTrackSendUIMute <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ToggleTrackSendUIMute>`_",""
	"`ValidatePtr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ValidatePtr>`_","`Project.has_valid_id <reapy.core.html#reapy.core.Project.has_valid_id>`_; `Track.has_valid_id <reapy.core.html#reapy.core.Track.has_valid_id>`_; `Item.has_valid_id <reapy.core.html#reapy.core.Item.has_valid_id>`_; `Take.has_valid_id <reapy.core.html#reapy.core.Take.has_valid_id>`_; `Envelope.has_valid_id <reapy.core.html#reapy.core.Envelope.has_valid_id>`_; `Source.has_valid_id <reapy.core.html#reapy.core.Source.has_valid_id>`_"
	"`ValidatePtr2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ValidatePtr2>`_","`Project.has_valid_id <reapy.core.html#reapy.core.Project.has_valid_id>`_; `Track.has_valid_id <reapy.core.html#reapy.core.Track.has_valid_id>`_; `Item.has_valid_id <reapy.core.html#reapy.core.Item.has_valid_id>`_; `Take.has_valid_id <reapy.core.html#reapy.core.Take.has_valid_id>`_; `Envelope.has_valid_id <reapy.core.html#reapy.core.Envelope.has_valid_id>`_; `Source.has_valid_id <reapy.core.html#reapy.core.Source.has_valid_id>`_"
	"`format_timestr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#format_timestr>`_",""
	"`format_timestr_len <https://www.reaper.fm/sdk/reascript/reascripthelp.html#format_timestr_len>`_",""
	"`format_timestr_pos <https://www.reaper.fm/sdk/reascript/reascripthelp.html#format_timestr_pos>`_",""
	"`genGuid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#genGuid>`_",""
	"`get_ini_file <https://www.reaper.fm/sdk/reascript/reascripthelp.html#get_ini_file>`_","`get_ini_file <reapy.core.reaper.html#reapy.core.reaper.reaper.get_ini_file>`_"
	"`guidToString <https://www.reaper.fm/sdk/reascript/reascripthelp.html#guidToString>`_",""
	"`image_resolve_fn <https://www.reaper.fm/sdk/reascript/reascripthelp.html#image_resolve_fn>`_",""
	"`mkpanstr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#mkpanstr>`_",""
	"`mkvolpanstr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#mkvolpanstr>`_",""
	"`mkvolstr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#mkvolstr>`_",""
	"`parse_timestr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#parse_timestr>`_",""
	"`parse_timestr_len <https://www.reaper.fm/sdk/reascript/reascripthelp.html#parse_timestr_len>`_",""
	"`parse_timestr_pos <https://www.reaper.fm/sdk/reascript/reascripthelp.html#parse_timestr_pos>`_",""
	"`parsepanstr <https://www.reaper.fm/sdk/reascript/reascripthelp.html#parsepanstr>`_",""
	"`relative_fn <https://www.reaper.fm/sdk/reascript/reascripthelp.html#relative_fn>`_",""
	"`resolve_fn <https://www.reaper.fm/sdk/reascript/reascripthelp.html#resolve_fn>`_",""
	"`resolve_fn2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#resolve_fn2>`_",""
	"`stringToGuid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#stringToGuid>`_",""
	"`time_precise <https://www.reaper.fm/sdk/reascript/reascripthelp.html#time_precise>`_","`time.time <reapy.core.reaper.html#reapy.core.reaper.time.time>`_"


Arrangeview Management
----------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`CSurf_OnArrow <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnArrow>`_",""
	"`CSurf_OnScroll <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnScroll>`_",""
	"`CSurf_OnZoom <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnZoom>`_",""
	"`GetCursorContext <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetCursorContext>`_",""
	"`GetCursorContext2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetCursorContext2>`_",""
	"`GetHZoomLevel <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetHZoomLevel>`_",""
	"`GetSet_ArrangeView2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSet_ArrangeView2>`_",""
	"`SetCursorContext <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetCursorContext>`_",""
	"`UpdateArrange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#UpdateArrange>`_","`update_arrange <reapy.core.reaper.html#reapy.core.reaper.reaper.update_arrange>`_"
	"`UpdateTimeline <https://www.reaper.fm/sdk/reascript/reascripthelp.html#UpdateTimeline>`_","`update_timeline <reapy.core.reaper.html#reapy.core.reaper.reaper.update_timeline>`_"
	"`adjustZoom <https://www.reaper.fm/sdk/reascript/reascripthelp.html#adjustZoom>`_",""


Audio Management
----------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`AudioAccessorValidateState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AudioAccessorValidateState>`_","`AudioAccessor.has_state_changed <reapy.core.html#reapy.core.AudioAccessor.has_state_changed>`_"
	"`CreateTakeAudioAccessor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CreateTakeAudioAccessor>`_","`Take.add_audio_accessor <reapy.core.html#reapy.core.Take.add_audio_accessor>`_"
	"`CreateTrackAudioAccessor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CreateTrackAudioAccessor>`_","`Track.add_audio_accessor <reapy.core.html#reapy.core.Track.add_audio_accessor>`_"
	"`DestroyAudioAccessor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DestroyAudioAccessor>`_","`AudioAccessor.delete <reapy.core.html#reapy.core.AudioAccessor.delete>`_"
	"`GetAudioAccessorEndTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAudioAccessorEndTime>`_","`AudioAccessor.end_time <reapy.core.html#reapy.core.AudioAccessor.end_time>`_"
	"`GetAudioAccessorHash <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAudioAccessorHash>`_","`AudioAccessor.hash <reapy.core.html#reapy.core.AudioAccessor.hash>`_"
	"`GetAudioAccessorSamples <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAudioAccessorSamples>`_","`AudioAccessor.get_samples <reapy.core.html#reapy.core.AudioAccessor.get_samples>`_"
	"`GetAudioAccessorStartTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAudioAccessorStartTime>`_","`AudioAccessor.start_time <reapy.core.html#reapy.core.AudioAccessor.start_time>`_"
	"`GetAudioDeviceInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAudioDeviceInfo>`_",""
	"`GetItemEditingTime2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetItemEditingTime2>`_",""
	"`GetMediaSourceFileName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceFileName>`_","`Source.filename <reapy.core.html#reapy.core.Source.filename>`_"
	"`GetMediaSourceLength <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceLength>`_","`Source.length <reapy.core.html#reapy.core.Source.length>`_"
	"`GetMediaSourceNumChannels <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceNumChannels>`_","`Source.n_channels <reapy.core.html#reapy.core.Source.n_channels>`_"
	"`GetMediaSourceParent <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceParent>`_",""
	"`GetMediaSourceSampleRate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceSampleRate>`_","`Source.sample_rate <reapy.core.html#reapy.core.Source.sample_rate>`_"
	"`GetMediaSourceType <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaSourceType>`_","`Source.type <reapy.core.html#reapy.core.Source.type>`_"
	"`GetPeakFileName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPeakFileName>`_",""
	"`GetPeakFileNameEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPeakFileNameEx>`_",""
	"`GetPeakFileNameEx2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPeakFileNameEx2>`_",""
	"`GetSubProjectFromSource <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSubProjectFromSource>`_",""
	"`GetTempoMatchPlayRate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTempoMatchPlayRate>`_",""
	"`InsertMedia <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertMedia>`_",""
	"`InsertMediaSection <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertMediaSection>`_",""
	"`PCM_Sink_Enum <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Sink_Enum>`_",""
	"`PCM_Sink_GetExtension <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Sink_GetExtension>`_",""
	"`PCM_Sink_ShowConfig <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Sink_ShowConfig>`_",""
	"`PCM_Source_CreateFromFile <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_CreateFromFile>`_",""
	"`PCM_Source_CreateFromFileEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_CreateFromFileEx>`_",""
	"`PCM_Source_CreateFromType <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_CreateFromType>`_",""
	"`PCM_Source_Destroy <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_Destroy>`_","`Source.delete <reapy.core.html#reapy.core.Source.delete>`_"
	"`PCM_Source_GetPeaks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_GetPeaks>`_",""
	"`PCM_Source_GetSectionInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PCM_Source_GetSectionInfo>`_",""
	"`Resample_EnumModes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Resample_EnumModes>`_",""


Audio/MIDI Device Management
----------------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`Audio_Init <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Audio_Init>`_","`audio.init <reapy.core.reaper.html#reapy.core.reaper.audio.init>`_"
	"`Audio_IsPreBuffer <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Audio_IsPreBuffer>`_","`audio.is_prebuffer <reapy.core.reaper.html#reapy.core.reaper.audio.is_prebuffer>`_"
	"`Audio_IsRunning <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Audio_IsRunning>`_","`audio.is_running <reapy.core.reaper.html#reapy.core.reaper.audio.is_running>`_"
	"`Audio_Quit <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Audio_Quit>`_","`audio.quit <reapy.core.reaper.html#reapy.core.reaper.audio.quit>`_"
	"`GetInputChannelName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetInputChannelName>`_","`audio.get_input_names <reapy.core.reaper.html#reapy.core.reaper.audio.get_input_names>`_"
	"`GetInputOutputLatency <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetInputOutputLatency>`_","`audio.get_input_latency <reapy.core.reaper.html#reapy.core.reaper.audio.get_input_latency>`_; `audio.get_output_latency <reapy.core.reaper.html#reapy.core.reaper.audio.get_output_latency>`_"
	"`GetMIDIInputName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMIDIInputName>`_","`midi.get_input_names <reapy.core.reaper.html#reapy.core.reaper.midi.get_input_names>`_"
	"`GetMIDIOutputName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMIDIOutputName>`_","`midi.get_output_names <reapy.core.reaper.html#reapy.core.reaper.midi.get_output_names>`_"
	"`GetMaxMidiInputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMaxMidiInputs>`_","`midi.get_max_inputs <reapy.core.reaper.html#reapy.core.reaper.midi.get_max_inputs>`_"
	"`GetMaxMidiOutputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMaxMidiOutputs>`_","`midi.get_max_outputs <reapy.core.reaper.html#reapy.core.reaper.midi.get_max_outputs>`_"
	"`GetNumAudioInputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetNumAudioInputs>`_","`audio.get_n_inputs <reapy.core.reaper.html#reapy.core.reaper.audio.get_n_inputs>`_"
	"`GetNumAudioOutputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetNumAudioOutputs>`_","`audio.get_n_outputs <reapy.core.reaper.html#reapy.core.reaper.audio.get_n_outputs>`_"
	"`GetNumMIDIInputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetNumMIDIInputs>`_","`midi.get_n_inputs <reapy.core.reaper.html#reapy.core.reaper.midi.get_n_inputs>`_"
	"`GetNumMIDIOutputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetNumMIDIOutputs>`_","`midi.get_n_outputs <reapy.core.reaper.html#reapy.core.reaper.midi.get_n_outputs>`_"
	"`GetOutputChannelName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetOutputChannelName>`_","`audio.get_output_names <reapy.core.reaper.html#reapy.core.reaper.audio.get_output_names>`_"
	"`GetOutputLatency <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetOutputLatency>`_","`audio.get_output_latency <reapy.core.reaper.html#reapy.core.reaper.audio.get_output_latency>`_"
	"`GetUnderrunTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetUnderrunTime>`_",""
	"`OscLocalMessageToHost <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OscLocalMessageToHost>`_",""


Automation Management
---------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`CountAutomationItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountAutomationItems>`_","`Envelope.n_items <reapy.core.html#reapy.core.Envelope.n_items>`_"
	"`GetSetAutomationItemInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetAutomationItemInfo>`_","`AutomationItem.length <reapy.core.html#reapy.core.AutomationItem.length>`_; `AutomationItem.pool <reapy.core.html#reapy.core.AutomationItem.pool>`_; `AutomationItem.position <reapy.core.html#reapy.core.AutomationItem.position>`_"
	"`InsertAutomationItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertAutomationItem>`_",""


Deferring Function Calls
------------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`atexit <https://www.reaper.fm/sdk/reascript/reascripthelp.html#python_atexit>`_","`at_exit <reapy.core.reaper.html#reapy.core.reaper.defer.at_exit>`_"
	"`defer <https://www.reaper.fm/sdk/reascript/reascripthelp.html#python_defer>`_","`defer <reapy.core.reaper.html#reapy.core.reaper.defer.defer>`_"


Envelope Management
-------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`CSurf_SetAutoMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetAutoMode>`_",""
	"`CountEnvelopePoints <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountEnvelopePoints>`_","`Envelope.n_points <reapy.core.html#reapy.core.Envelope.n_points>`_"
	"`CountEnvelopePointsEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountEnvelopePointsEx>`_","`AutomationItem.n_points <reapy.core.html#reapy.core.AutomationItem.n_points>`_"
	"`CountTrackEnvelopes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTrackEnvelopes>`_","`Track.n_envelopes <reapy.core.html#reapy.core.Track.n_envelopes>`_"
	"`DeleteEnvelopePointRange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteEnvelopePointRange>`_","`Envelope.delete_points_in_range <reapy.core.html#reapy.core.Envelope.delete_points_in_range>`_"
	"`DeleteEnvelopePointRangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteEnvelopePointRangeEx>`_","`AutomationItem.delete_points_in_range <reapy.core.html#reapy.core.AutomationItem.delete_points_in_range>`_"
	"`Envelope_Evaluate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_Evaluate>`_","`Envelope.get_value <reapy.core.html#reapy.core.Envelope.get_value>`_; `Envelope.get_derivatives <reapy.core.html#reapy.core.Envelope.get_derivatives>`_"
	"`Envelope_FormatValue <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_FormatValue>`_","`Envelope.get_value <reapy.core.html#reapy.core.Envelope.get_value>`_; `Envelope.get_derivatives <reapy.core.html#reapy.core.Envelope.get_derivatives>`_"
	"`Envelope_GetParentTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_GetParentTake>`_","`Envelope.parent <reapy.core.html#reapy.core.Envelope.parent>`_"
	"`Envelope_GetParentTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_GetParentTrack>`_","`Envelope.parent <reapy.core.html#reapy.core.Envelope.parent>`_"
	"`Envelope_SortPoints <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_SortPoints>`_",""
	"`Envelope_SortPointsEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Envelope_SortPointsEx>`_",""
	"`GetEnvelopeName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopeName>`_","`Envelope.name <reapy.core.html#reapy.core.Envelope.name>`_"
	"`GetEnvelopePoint <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopePoint>`_",""
	"`GetEnvelopePointByTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopePointByTime>`_",""
	"`GetEnvelopePointByTimeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopePointByTimeEx>`_",""
	"`GetEnvelopePointEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopePointEx>`_",""
	"`GetEnvelopeScalingMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopeScalingMode>`_",""
	"`GetEnvelopeStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetEnvelopeStateChunk>`_",""
	"`GetFXEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetFXEnvelope>`_","`FXParam.envelope <reapy.core.html#reapy.core.FXParam.envelope>`_; `FXParam.add_envelope <reapy.core.html#reapy.core.FXParam.add_envelope>`_"
	"`GetGlobalAutomationOverride <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetGlobalAutomationOverride>`_","`get_global_automation_mode <reapy.core.reaper.html#reapy.core.reaper.reaper.get_global_automation_mode>`_"
	"`GetSelectedEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSelectedEnvelope>`_","`Project.selected_envelope <reapy.core.html#reapy.core.Project.selected_envelope>`_"
	"`GetSelectedTrackEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSelectedTrackEnvelope>`_","`Project.selected_envelope <reapy.core.html#reapy.core.Project.selected_envelope>`_"
	"`GetSetEnvelopeState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetEnvelopeState>`_","DEPRECATED"
	"`GetSetEnvelopeState2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetEnvelopeState2>`_","DEPRECATED"
	"`GetTakeEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeEnvelope>`_","`Take.envelopes <reapy.core.html#reapy.core.Take.envelopes>`_"
	"`GetTakeEnvelopeByName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeEnvelopeByName>`_","`Take.envelopes <reapy.core.html#reapy.core.Take.envelopes>`_"
	"`GetTrackAutomationMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackAutomationMode>`_","`Track.automation_mode <reapy.core.html#reapy.core.Track.automation_mode>`_"
	"`GetTrackEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackEnvelope>`_","`Track.envelopes <reapy.core.html#reapy.core.Track.envelopes>`_"
	"`GetTrackEnvelopeByChunkName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackEnvelopeByChunkName>`_","`Track.envelopes <reapy.core.html#reapy.core.Track.envelopes>`_"
	"`GetTrackEnvelopeByName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackEnvelopeByName>`_","`Track.envelopes <reapy.core.html#reapy.core.Track.envelopes>`_"
	"`InsertEnvelopePoint <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertEnvelopePoint>`_",""
	"`InsertEnvelopePointEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertEnvelopePointEx>`_",""
	"`ScaleFromEnvelopeMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ScaleFromEnvelopeMode>`_",""
	"`ScaleToEnvelopeMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ScaleToEnvelopeMode>`_",""
	"`SetAutomationMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetAutomationMode>`_",""
	"`SetEnvelopePoint <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetEnvelopePoint>`_",""
	"`SetEnvelopePointEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetEnvelopePointEx>`_",""
	"`SetEnvelopeStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetEnvelopeStateChunk>`_",""
	"`SetGlobalAutomationOverride <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetGlobalAutomationOverride>`_","`set_global_automation_mode <reapy.core.reaper.html#reapy.core.reaper.reaper.set_global_automation_mode>`_"
	"`SetTrackAutomationMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackAutomationMode>`_","`Track.automation_mode <reapy.core.html#reapy.core.Track.automation_mode>`_"


Extended States
---------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`DeleteExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteExtState>`_","`delete_ext_state <reapy.core.reaper.html#reapy.core.reaper.reaper.delete_ext_state>`_"
	"`GetExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetExtState>`_","`get_ext_state <reapy.core.reaper.html#reapy.core.reaper.reaper.get_ext_state>`_"
	"`HasExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#HasExtState>`_","`has_ext_state <reapy.core.reaper.html#reapy.core.reaper.reaper.has_ext_state>`_"
	"`SetExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetExtState>`_","`set_ext_state <reapy.core.reaper.html#reapy.core.reaper.reaper.set_ext_state>`_"


FX Management
-------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`GetFocusedFX <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetFocusedFX>`_","`Project.focused_fx <reapy.core.html#reapy.core.Project.focused_fx>`_"
	"`GetLastTouchedFX <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetLastTouchedFX>`_","`Project.last_touched_fx <reapy.core.html#reapy.core.Project.last_touched_fx>`_"
	"`GetTCPFXParm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTCPFXParm>`_",""
	"`PluginWantsAlwaysRunFx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PluginWantsAlwaysRunFx>`_",""
	"`TakeFX_AddByName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_AddByName>`_","`Take.add_fx <reapy.core.html#reapy.core.Take.add_fx>`_"
	"`TakeFX_CopyToTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_CopyToTake>`_","`FX.copy_to_take <reapy.core.html#reapy.core.FX.copy_to_take>`_; `FX.move_to_take <reapy.core.html#reapy.core.FX.move_to_take>`_"
	"`TakeFX_CopyToTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_CopyToTrack>`_","`FX.copy_to_track <reapy.core.html#reapy.core.FX.copy_to_track>`_; `FX.move_to_track <reapy.core.html#reapy.core.FX.move_to_track>`_"
	"`TakeFX_Delete <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_Delete>`_","`FX.delete <reapy.core.html#reapy.core.FX.delete>`_"
	"`TakeFX_EndParamEdit <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_EndParamEdit>`_",""
	"`TakeFX_FormatParamValue <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_FormatParamValue>`_","`FXParam.format_value <reapy.core.html#reapy.core.FXParam.format_value>`_"
	"`TakeFX_FormatParamValueNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_FormatParamValueNormalized>`_","`NormalizedFXParam.format_value <reapy.core.html#reapy.core.NormalizedFXParam.format_value>`_"
	"`TakeFX_GetChainVisible <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetChainVisible>`_","`Take.visible_fx <reapy.core.html#reapy.core.Take.visible_fx>`_"
	"`TakeFX_GetCount <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetCount>`_","`Take.n_fxs <reapy.core.html#reapy.core.Take.n_fxs>`_"
	"`TakeFX_GetEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetEnabled>`_","`FX.is_enabled <reapy.core.html#reapy.core.FX.is_enabled>`_"
	"`TakeFX_GetEnvelope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetEnvelope>`_","`FXParam.envelope <reapy.core.html#reapy.core.FXParam.envelope>`_; `FXParam.add_envelope <reapy.core.html#reapy.core.FXParam.add_envelope>`_"
	"`TakeFX_GetFXGUID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetFXGUID>`_",""
	"`TakeFX_GetFXName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetFXName>`_","`FX.name <reapy.core.html#reapy.core.FX.name>`_"
	"`TakeFX_GetFloatingWindow <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetFloatingWindow>`_","`FX.window <reapy.core.html#reapy.core.FX.window>`_"
	"`TakeFX_GetFormattedParamValue <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetFormattedParamValue>`_","`FXParam.formatted <reapy.core.html#reapy.core.FXParam.formatted>`_"
	"`TakeFX_GetIOSize <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetIOSize>`_","`FX.n_inputs <reapy.core.html#reapy.core.FX.n_inputs>`_; `FX.n_outputs <reapy.core.html#reapy.core.FX.n_outputs>`_"
	"`TakeFX_GetNamedConfigParm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetNamedConfigParm>`_",""
	"`TakeFX_GetNumParams <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetNumParams>`_","`FX.n_params <reapy.core.html#reapy.core.FX.n_params>`_"
	"`TakeFX_GetOffline <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetOffline>`_","`FX.is_online <reapy.core.html#reapy.core.FX.is_online>`_"
	"`TakeFX_GetOpen <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetOpen>`_","`FX.is_ui_open <reapy.core.html#reapy.core.FX.is_ui_open>`_"
	"`TakeFX_GetParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetParam>`_","`FX.params <reapy.core.html#reapy.core.FX.params>`_"
	"`TakeFX_GetParamEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetParamEx>`_","`FX.params <reapy.core.html#reapy.core.FX.params>`_"
	"`TakeFX_GetParamName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetParamName>`_","`FXParam.name <reapy.core.html#reapy.core.FXParam.name>`_"
	"`TakeFX_GetParamNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetParamNormalized>`_","`FXParam.normalized <reapy.core.html#reapy.core.FXParam.normalized>`_"
	"`TakeFX_GetParameterStepSizes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetParameterStepSizes>`_",""
	"`TakeFX_GetPinMappings <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetPinMappings>`_",""
	"`TakeFX_GetPreset <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetPreset>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TakeFX_GetPresetIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetPresetIndex>`_","`FX.preset_index <reapy.core.html#reapy.core.FX.preset_index>`_"
	"`TakeFX_GetUserPresetFilename <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_GetUserPresetFilename>`_","`FX.preset_file <reapy.core.html#reapy.core.FX.preset_file>`_"
	"`TakeFX_NavigatePresets <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_NavigatePresets>`_","`FX.use_next_preset <reapy.core.html#reapy.core.FX.use_next_preset>`_; `FX.use_previous_preset <reapy.core.html#reapy.core.FX.use_previous_preset>`_"
	"`TakeFX_SetEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetEnabled>`_","`FX.enable <reapy.core.html#reapy.core.FX.enable>`_; `FX.disable <reapy.core.html#reapy.core.FX.disable>`_"
	"`TakeFX_SetNamedConfigParm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetNamedConfigParm>`_",""
	"`TakeFX_SetOffline <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetOffline>`_","`FX.make_online <reapy.core.html#reapy.core.FX.make_online>`_; `FX.make_offline <reapy.core.html#reapy.core.FX.make_offline>`_"
	"`TakeFX_SetOpen <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetOpen>`_","`FX.open_ui <reapy.core.html#reapy.core.FX.open_ui>`_; `FX.close_ui <reapy.core.html#reapy.core.FX.close_ui>`_"
	"`TakeFX_SetParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetParam>`_","`FX.params <reapy.core.html#reapy.core.FX.params>`_"
	"`TakeFX_SetParamNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetParamNormalized>`_","`FXParam.normalized <reapy.core.html#reapy.core.FXParam.normalized>`_"
	"`TakeFX_SetPinMappings <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetPinMappings>`_",""
	"`TakeFX_SetPreset <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetPreset>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TakeFX_SetPresetByIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_SetPresetByIndex>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TakeFX_Show <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeFX_Show>`_","`FX.open_chain <reapy.core.html#reapy.core.FX.open_chain>`_; `FX.open_floating_window <reapy.core.html#reapy.core.FX.open_floating_window>`_; `FX.close_chain <reapy.core.html#reapy.core.FX.close_chain>`_; `FX.close_floating_window <reapy.core.html#reapy.core.FX.close_floating_window>`_"
	"`TrackFX_AddByName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_AddByName>`_","`Track.add_fx <reapy.core.html#reapy.core.Track.add_fx>`_"
	"`TrackFX_CopyToTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_CopyToTake>`_","`FX.copy_to_take <reapy.core.html#reapy.core.FX.copy_to_take>`_; `FX.move_to_take <reapy.core.html#reapy.core.FX.move_to_take>`_"
	"`TrackFX_CopyToTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_CopyToTrack>`_","`FX.copy_to_track <reapy.core.html#reapy.core.FX.copy_to_track>`_; `FX.move_to_track <reapy.core.html#reapy.core.FX.move_to_track>`_"
	"`TrackFX_Delete <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_Delete>`_","`FX.delete <reapy.core.html#reapy.core.FX.delete>`_"
	"`TrackFX_EndParamEdit <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_EndParamEdit>`_",""
	"`TrackFX_FormatParamValue <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_FormatParamValue>`_","`FXParam.format_value <reapy.core.html#reapy.core.FXParam.format_value>`_"
	"`TrackFX_FormatParamValueNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_FormatParamValueNormalized>`_","`NormalizedFXParam.format_value <reapy.core.html#reapy.core.NormalizedFXParam.format_value>`_"
	"`TrackFX_GetByName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetByName>`_",""
	"`TrackFX_GetChainVisible <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetChainVisible>`_","`Track.visible_fx <reapy.core.html#reapy.core.Track.visible_fx>`_"
	"`TrackFX_GetCount <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetCount>`_","`Track.n_fxs <reapy.core.html#reapy.core.Track.n_fxs>`_"
	"`TrackFX_GetEQ <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetEQ>`_",""
	"`TrackFX_GetEQBandEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetEQBandEnabled>`_",""
	"`TrackFX_GetEQParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetEQParam>`_",""
	"`TrackFX_GetEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetEnabled>`_","`FX.is_enabled <reapy.core.html#reapy.core.FX.is_enabled>`_"
	"`TrackFX_GetFXGUID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetFXGUID>`_",""
	"`TrackFX_GetFXName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetFXName>`_","`FX.name <reapy.core.html#reapy.core.FX.name>`_"
	"`TrackFX_GetFloatingWindow <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetFloatingWindow>`_","`FX.window <reapy.core.html#reapy.core.FX.window>`_"
	"`TrackFX_GetFormattedParamValue <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetFormattedParamValue>`_","`FXParam.formatted <reapy.core.html#reapy.core.FXParam.formatted>`_"
	"`TrackFX_GetIOSize <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetIOSize>`_","`FX.n_inputs <reapy.core.html#reapy.core.FX.n_inputs>`_; `FX.n_outputs <reapy.core.html#reapy.core.FX.n_outputs>`_"
	"`TrackFX_GetInstrument <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetInstrument>`_","`Track.instrument <reapy.core.html#reapy.core.Track.instrument>`_"
	"`TrackFX_GetNamedConfigParm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetNamedConfigParm>`_",""
	"`TrackFX_GetNumParams <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetNumParams>`_","`FX.n_params <reapy.core.html#reapy.core.FX.n_params>`_"
	"`TrackFX_GetOffline <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetOffline>`_","`FX.is_online <reapy.core.html#reapy.core.FX.is_online>`_"
	"`TrackFX_GetParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetParam>`_","`FX.params <reapy.core.html#reapy.core.FX.params>`_"
	"`TrackFX_GetParamEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetParamEx>`_",""
	"`TrackFX_GetParamName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetParamName>`_","`FXParam.name <reapy.core.html#reapy.core.FXParam.name>`_"
	"`TrackFX_GetParamNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetParamNormalized>`_","`FXParam.normalized <reapy.core.html#reapy.core.FXParam.normalized>`_"
	"`TrackFX_GetParameterStepSizes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetParameterStepSizes>`_",""
	"`TrackFX_GetPinMappings <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetPinMappings>`_",""
	"`TrackFX_GetPreset <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetPreset>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TrackFX_GetPresetIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetPresetIndex>`_","`FX.preset_index <reapy.core.html#reapy.core.FX.preset_index>`_"
	"`TrackFX_GetRecChainVisible <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetRecChainVisible>`_",""
	"`TrackFX_GetRecCount <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetRecCount>`_",""
	"`TrackFX_GetUserPresetFilename <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetUserPresetFilename>`_","`FX.preset_file <reapy.core.html#reapy.core.FX.preset_file>`_"
	"`TrackFX_NavigatePresets <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_NavigatePresets>`_","`FX.use_next_preset <reapy.core.html#reapy.core.FX.use_next_preset>`_; `FX.use_previous_preset <reapy.core.html#reapy.core.FX.use_previous_preset>`_"
	"`TrackFX_SetEQBandEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetEQBandEnabled>`_",""
	"`TrackFX_SetEQParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetEQParam>`_",""
	"`TrackFX_SetEnabled <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetEnabled>`_","`FX.enable <reapy.core.html#reapy.core.FX.enable>`_; `FX.disable <reapy.core.html#reapy.core.FX.disable>`_"
	"`TrackFX_SetNamedConfigParm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetNamedConfigParm>`_",""
	"`TrackFX_SetOffline <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetOffline>`_","`FX.make_online <reapy.core.html#reapy.core.FX.make_online>`_; `FX.make_offline <reapy.core.html#reapy.core.FX.make_offline>`_"
	"`TrackFX_SetParam <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetParam>`_","`FX.params <reapy.core.html#reapy.core.FX.params>`_"
	"`TrackFX_SetParamNormalized <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetParamNormalized>`_","`FXParam.normalized <reapy.core.html#reapy.core.FXParam.normalized>`_"
	"`TrackFX_SetPinMappings <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetPinMappings>`_",""
	"`TrackFX_SetPreset <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetPreset>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TrackFX_SetPresetByIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetPresetByIndex>`_","`FX.preset <reapy.core.html#reapy.core.FX.preset>`_"
	"`TrackList_AdjustWindows <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackList_AdjustWindows>`_",""


File Management
---------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`EnumerateFiles <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumerateFiles>`_","`os.listdir <reapy.core.reaper.html#reapy.core.reaper.os.listdir>`_"
	"`EnumerateSubdirectories <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumerateSubdirectories>`_","`os.listdir <reapy.core.reaper.html#reapy.core.reaper.os.listdir>`_"
	"`file_exists <https://www.reaper.fm/sdk/reascript/reascripthelp.html#file_exists>`_","`os.path.isfile <reapy.core.reaper.html#reapy.core.reaper.os.path.isfile>`_"


Item Management
---------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`AddMediaItemToTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddMediaItemToTrack>`_","`Track.add_item <reapy.core.html#reapy.core.Track.add_item>`_"
	"`AddTakeToMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddTakeToMediaItem>`_","`Item.add_take <reapy.core.html#reapy.core.Item.add_take>`_"
	"`ApplyNudge <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ApplyNudge>`_",""
	"`CountMediaItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountMediaItems>`_","`Project.n_items <reapy.core.html#reapy.core.Project.n_items>`_"
	"`CountSelectedMediaItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountSelectedMediaItems>`_","`Project.n_selected_items <reapy.core.html#reapy.core.Project.n_selected_items>`_"
	"`CountTakeEnvelopes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTakeEnvelopes>`_","`Take.n_envelopes <reapy.core.html#reapy.core.Take.n_envelopes>`_"
	"`CountTakes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTakes>`_","`Item.n_takes <reapy.core.html#reapy.core.Item.n_takes>`_"
	"`CountTrackMediaItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTrackMediaItems>`_","`Track.n_items <reapy.core.html#reapy.core.Track.n_items>`_"
	"`CreateNewMIDIItemInProj <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CreateNewMIDIItemInProj>`_","`Track.add_midi_item <reapy.core.html#reapy.core.Track.add_midi_item>`_"
	"`DeleteTrackMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteTrackMediaItem>`_","`Item.delete <reapy.core.html#reapy.core.Item.delete>`_"
	"`GetActiveTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetActiveTake>`_","`Item.active_take <reapy.core.html#reapy.core.Item.active_take>`_"
	"`GetDisplayedMediaItemColor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetDisplayedMediaItemColor>`_",""
	"`GetDisplayedMediaItemColor2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetDisplayedMediaItemColor2>`_",""
	"`GetItemProjectContext <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetItemProjectContext>`_","`Item.project <reapy.core.html#reapy.core.Item.project>`_"
	"`GetItemStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetItemStateChunk>`_",""
	"`GetMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItem>`_","`Project.items <reapy.core.html#reapy.core.Project.items>`_"
	"`GetMediaItemInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemInfo_Value>`_","`Item.get_info_value <reapy.core.html#reapy.core.Item.get_info_value>`_"
	"`GetMediaItemNumTakes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemNumTakes>`_","`Item.n_takes <reapy.core.html#reapy.core.Item.n_takes>`_"
	"`GetMediaItemTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTake>`_","`Item.takes <reapy.core.html#reapy.core.Item.takes>`_; `Item.get_take <reapy.core.html#reapy.core.Item.get_take>`_"
	"`GetMediaItemTakeByGUID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTakeByGUID>`_",""
	"`GetMediaItemTakeInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTakeInfo_Value>`_","`Take.get_info_value <reapy.core.html#reapy.core.Take.get_info_value>`_"
	"`GetMediaItemTake_Item <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTake_Item>`_","`Take.item <reapy.core.html#reapy.core.Take.item>`_"
	"`GetMediaItemTake_Peaks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTake_Peaks>`_",""
	"`GetMediaItemTake_Source <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTake_Source>`_","`Take.source <reapy.core.html#reapy.core.Take.source>`_"
	"`GetMediaItemTake_Track <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTake_Track>`_","`Take.track <reapy.core.html#reapy.core.Take.track>`_"
	"`GetSelectedMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSelectedMediaItem>`_","`Project.selected_items <reapy.core.html#reapy.core.Project.selected_items>`_; `Project.get_selected_item <reapy.core.html#reapy.core.Project.get_selected_item>`_"
	"`GetSetItemState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetItemState>`_","DEPRECATED"
	"`GetSetItemState2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetItemState2>`_","DEPRECATED"
	"`GetSetMediaItemInfo_String <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetMediaItemInfo_String>`_",""
	"`GetSetMediaItemTakeInfo_String <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetMediaItemTakeInfo_String>`_",""
	"`GetTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTake>`_","`Item.takes <reapy.core.html#reapy.core.Item.takes>`_"
	"`GetTakeName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeName>`_","`Take.name <reapy.core.html#reapy.core.Take.name>`_"
	"`GetTrackMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackMediaItem>`_","`Track.items <reapy.core.html#reapy.core.Track.items>`_"
	"`IsMediaItemSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#IsMediaItemSelected>`_","`Item.is_selected <reapy.core.html#reapy.core.Item.is_selected>`_"
	"`MoveMediaItemToTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MoveMediaItemToTrack>`_","`Item.track <reapy.core.html#reapy.core.Item.track>`_"
	"`SelectAllMediaItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SelectAllMediaItems>`_","`Project.select_all_items <reapy.core.html#reapy.core.Project.select_all_items>`_"
	"`SetActiveTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetActiveTake>`_","`Take.make_active_take <reapy.core.html#reapy.core.Take.make_active_take>`_"
	"`SetItemStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetItemStateChunk>`_",""
	"`SetMediaItemInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemInfo_Value>`_",""
	"`SetMediaItemLength <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemLength>`_","`Item.length <reapy.core.html#reapy.core.Item.length>`_"
	"`SetMediaItemPosition <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemPosition>`_","`Item.position <reapy.core.html#reapy.core.Item.position>`_"
	"`SetMediaItemSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemSelected>`_",""
	"`SetMediaItemTakeInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemTakeInfo_Value>`_",""
	"`SetMediaItemTake_Source <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaItemTake_Source>`_",""
	"`SplitMediaItem <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SplitMediaItem>`_","`Item.split <reapy.core.html#reapy.core.Item.split>`_"
	"`UpdateItemInProject <https://www.reaper.fm/sdk/reascript/reascripthelp.html#UpdateItemInProject>`_","`Item.update <reapy.core.html#reapy.core.Item.update>`_"


Joystick Management
-------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`joystick_create <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_create>`_",""
	"`joystick_destroy <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_destroy>`_",""
	"`joystick_enum <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_enum>`_",""
	"`joystick_getaxis <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_getaxis>`_",""
	"`joystick_getbuttonmask <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_getbuttonmask>`_",""
	"`joystick_getinfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_getinfo>`_",""
	"`joystick_getpov <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_getpov>`_",""
	"`joystick_update <https://www.reaper.fm/sdk/reascript/reascripthelp.html#joystick_update>`_",""


MIDI Management
---------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`EnumTrackMIDIProgramNames <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumTrackMIDIProgramNames>`_",""
	"`EnumTrackMIDIProgramNamesEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumTrackMIDIProgramNamesEx>`_",""
	"`GetTrackMIDILyrics <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackMIDILyrics>`_",""
	"`GetTrackMIDINoteName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackMIDINoteName>`_",""
	"`GetTrackMIDINoteNameEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackMIDINoteNameEx>`_",""
	"`GetTrackMIDINoteRange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackMIDINoteRange>`_",""
	"`HasTrackMIDIPrograms <https://www.reaper.fm/sdk/reascript/reascripthelp.html#HasTrackMIDIPrograms>`_",""
	"`HasTrackMIDIProgramsEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#HasTrackMIDIProgramsEx>`_",""
	"`MIDIEditor_GetActive <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_GetActive>`_","`midi.get_active_editor <reapy.core.reaper.html#reapy.core.reaper.midi.get_active_editor>`_"
	"`MIDIEditor_GetMode <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_GetMode>`_","`MIDIEditor.mode <reapy.core.html#reapy.core.MIDIEditor.mode>`_"
	"`MIDIEditor_GetSetting_int <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_GetSetting_int>`_","`MIDIEditor <reapy.core.html#reapy.core.MIDIEditor>`_"
	"`MIDIEditor_GetSetting_str <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_GetSetting_str>`_","`MIDIEditor <reapy.core.html#reapy.core.MIDIEditor>`_"
	"`MIDIEditor_GetTake <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_GetTake>`_","`MIDIEditor.take <reapy.core.html#reapy.core.MIDIEditor.take>`_"
	"`MIDIEditor_LastFocused_OnCommand <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_LastFocused_OnCommand>`_","`midi.get_active_editor <reapy.core.reaper.html#reapy.core.reaper.midi.get_active_editor>`_; `MIDIEditor.perform_action <reapy.core.html#reapy.core.MIDIEditor.perform_action>`_"
	"`MIDIEditor_OnCommand <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDIEditor_OnCommand>`_","`MIDIEditor.perform_action <reapy.core.html#reapy.core.MIDIEditor.perform_action>`_"
	"`MIDI_CountEvts <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_CountEvts>`_","`Take.n_cc <reapy.core.html#reapy.core.Take.n_cc>`_; `Take.n_notes <reapy.core.html#reapy.core.Take.n_notes>`_; `Take.n_text_sysex <reapy.core.html#reapy.core.Take.n_text_sysex>`_"
	"`MIDI_DeleteCC <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_DeleteCC>`_",""
	"`MIDI_DeleteEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_DeleteEvt>`_",""
	"`MIDI_DeleteNote <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_DeleteNote>`_",""
	"`MIDI_DeleteTextSysexEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_DeleteTextSysexEvt>`_",""
	"`MIDI_EnumSelCC <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_EnumSelCC>`_",""
	"`MIDI_EnumSelEvts <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_EnumSelEvts>`_",""
	"`MIDI_EnumSelNotes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_EnumSelNotes>`_",""
	"`MIDI_EnumSelTextSysexEvts <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_EnumSelTextSysexEvts>`_",""
	"`MIDI_GetAllEvts <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetAllEvts>`_",""
	"`MIDI_GetCC <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetCC>`_",""
	"`MIDI_GetEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetEvt>`_",""
	"`MIDI_GetGrid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetGrid>`_",""
	"`MIDI_GetHash <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetHash>`_",""
	"`MIDI_GetNote <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetNote>`_","`Take.notes <reapy.core.html#reapy.core.Take.notes>`_; `Note <reapy.core.html#reapy.core.Note>`_"
	"`MIDI_GetPPQPosFromProjQN <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetPPQPosFromProjQN>`_","`Take.beat_to_ppq <reapy.core.html#reapy.core.Take.beat_to_ppq>`_"
	"`MIDI_GetPPQPosFromProjTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetPPQPosFromProjTime>`_","`Take.time_to_ppq <reapy.core.html#reapy.core.Take.time_to_ppq>`_"
	"`MIDI_GetPPQPos_EndOfMeasure <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetPPQPos_EndOfMeasure>`_",""
	"`MIDI_GetPPQPos_StartOfMeasure <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetPPQPos_StartOfMeasure>`_",""
	"`MIDI_GetProjQNFromPPQPos <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetProjQNFromPPQPos>`_","`Take.ppq_to_beat <reapy.core.html#reapy.core.Take.ppq_to_beat>`_"
	"`MIDI_GetProjTimeFromPPQPos <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetProjTimeFromPPQPos>`_","`Take.ppq_to_time <reapy.core.html#reapy.core.Take.ppq_to_time>`_"
	"`MIDI_GetScale <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetScale>`_",""
	"`MIDI_GetTextSysexEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetTextSysexEvt>`_",""
	"`MIDI_GetTrackHash <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_GetTrackHash>`_",""
	"`MIDI_InsertCC <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_InsertCC>`_",""
	"`MIDI_InsertEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_InsertEvt>`_",""
	"`MIDI_InsertNote <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_InsertNote>`_","`Take.add_note <reapy.core.html#reapy.core.Take.add_note>`_"
	"`MIDI_InsertTextSysexEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_InsertTextSysexEvt>`_",""
	"`MIDI_SelectAll <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SelectAll>`_","`Take.select_all_midi_events <reapy.core.html#reapy.core.Take.select_all_midi_events>`_; `Take.unselect_all_midi_events <reapy.core.html#reapy.core.Take.unselect_all_midi_events>`_"
	"`MIDI_SetAllEvts <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetAllEvts>`_",""
	"`MIDI_SetCC <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetCC>`_",""
	"`MIDI_SetEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetEvt>`_",""
	"`MIDI_SetItemExtents <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetItemExtents>`_",""
	"`MIDI_SetNote <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetNote>`_",""
	"`MIDI_SetTextSysexEvt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_SetTextSysexEvt>`_",""
	"`MIDI_Sort <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MIDI_Sort>`_","`Take.sort_events <reapy.core.html#reapy.core.Take.sort_events>`_"
	"`SetMIDIEditorGrid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMIDIEditorGrid>`_",""
	"`SetTrackMIDILyrics <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackMIDILyrics>`_",""
	"`SetTrackMIDINoteName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackMIDINoteName>`_",""
	"`SetTrackMIDINoteNameEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackMIDINoteNameEx>`_",""
	"`StuffMIDIMessage <https://www.reaper.fm/sdk/reascript/reascripthelp.html#StuffMIDIMessage>`_",""
	"`TakeIsMIDI <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TakeIsMIDI>`_","`Take.is_midi <reapy.core.html#reapy.core.Take.is_midi>`_"
	"`midi_reinit <https://www.reaper.fm/sdk/reascript/reascripthelp.html#midi_reinit>`_","`midi.reinit <reapy.core.reaper.html#reapy.core.reaper.midi.reinit>`_"


Marker and Region Management
----------------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`AddProjectMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddProjectMarker>`_","`Project.add_marker <reapy.core.html#reapy.core.Project.add_marker>`_; `Project.add_region <reapy.core.html#reapy.core.Project.add_region>`_"
	"`AddProjectMarker2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddProjectMarker2>`_","`Project.add_marker <reapy.core.html#reapy.core.Project.add_marker>`_; `Project.add_region <reapy.core.html#reapy.core.Project.add_region>`_"
	"`AddTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AddTempoTimeSigMarker>`_","DEPRECATED"
	"`CountProjectMarkers <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountProjectMarkers>`_","`Project.n_markers <reapy.core.html#reapy.core.Project.n_markers>`_; `Project.n_regions <reapy.core.html#reapy.core.Project.n_regions>`_"
	"`CountTempoTimeSigMarkers <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTempoTimeSigMarkers>`_","`Project.n_tempo_markers <reapy.core.html#reapy.core.Project.n_tempo_markers>`_"
	"`DeleteProjectMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteProjectMarker>`_","`Marker.delete <reapy.core.html#reapy.core.Marker.delete>`_; `Region.delete <reapy.core.html#reapy.core.Region.delete>`_"
	"`DeleteProjectMarkerByIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteProjectMarkerByIndex>`_","`Marker.delete <reapy.core.html#reapy.core.Marker.delete>`_; `Region.delete <reapy.core.html#reapy.core.Region.delete>`_"
	"`DeleteTakeStretchMarkers <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteTakeStretchMarkers>`_",""
	"`DeleteTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteTempoTimeSigMarker>`_",""
	"`EditTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EditTempoTimeSigMarker>`_",""
	"`EnumProjectMarkers <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumProjectMarkers>`_","`Project.markers <reapy.core.html#reapy.core.Project.markers>`_; `Project.regions <reapy.core.html#reapy.core.Project.regions>`_"
	"`EnumProjectMarkers2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumProjectMarkers2>`_","`Project.markers <reapy.core.html#reapy.core.Project.markers>`_; `Project.regions <reapy.core.html#reapy.core.Project.regions>`_"
	"`EnumProjectMarkers3 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumProjectMarkers3>`_","`Project.markers <reapy.core.html#reapy.core.Project.markers>`_; `Project.regions <reapy.core.html#reapy.core.Project.regions>`_"
	"`FindTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#FindTempoTimeSigMarker>`_",""
	"`GetLastMarkerAndCurRegion <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetLastMarkerAndCurRegion>`_",""
	"`GetProjectTimeSignature <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectTimeSignature>`_","DEPRECATED"
	"`GetProjectTimeSignature2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectTimeSignature2>`_","`Project.bpm <reapy.core.html#reapy.core.Project.bpm>`_; `Project.bpi <reapy.core.html#reapy.core.Project.bpi>`_"
	"`GetTakeNumStretchMarkers <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeNumStretchMarkers>`_",""
	"`GetTakeStretchMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeStretchMarker>`_",""
	"`GetTakeStretchMarkerSlope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTakeStretchMarkerSlope>`_",""
	"`GetTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTempoTimeSigMarker>`_",""
	"`SetProjectMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarker>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetProjectMarker2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarker2>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetProjectMarker3 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarker3>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetProjectMarker4 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarker4>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetProjectMarkerByIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarkerByIndex>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetProjectMarkerByIndex2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectMarkerByIndex2>`_","`Marker <reapy.core.html#reapy.core.Marker>`_; `Region <reapy.core.html#reapy.core.Region>`_"
	"`SetTakeStretchMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTakeStretchMarker>`_",""
	"`SetTakeStretchMarkerSlope <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTakeStretchMarkerSlope>`_",""
	"`SetTempoTimeSigMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTempoTimeSigMarker>`_",""


Other
-----

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`ArmCommand <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ArmCommand>`_","`arm_command <reapy.core.reaper.html#reapy.core.reaper.reaper.arm_command>`_; `disarm_command <reapy.core.reaper.html#reapy.core.reaper.reaper.disarm_command>`_"
	"`CSurf_FlushUndo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_FlushUndo>`_",""
	"`CSurf_SetTrackListChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetTrackListChange>`_",""
	"`EnsureNotCompletelyOffscreen <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnsureNotCompletelyOffscreen>`_",""
	"`GetArmedCommand <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetArmedCommand>`_","`get_armed_command <reapy.core.reaper.html#reapy.core.reaper.reaper.get_armed_command>`_"
	"`Help_Set <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Help_Set>`_",""
	"`Main_UpdateLoopInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Main_UpdateLoopInfo>`_",""
	"`MarkTrackItemsDirty <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MarkTrackItemsDirty>`_",""
	"`MediaItemDescendsFromTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MediaItemDescendsFromTrack>`_",""
	"`RenderFileSection <https://www.reaper.fm/sdk/reascript/reascripthelp.html#RenderFileSection>`_",""
	"`SetRegionRenderMatrix <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetRegionRenderMatrix>`_","`Region.add_rendered_track <reapy.core.html#reapy.core.Region.add_rendered_track>`_; `Region.remove_rendered_track <reapy.core.html#reapy.core.Region.remove_rendered_track>`_"
	"`Splash_GetWnd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Splash_GetWnd>`_",""
	"`TimeMap2_GetDividedBpmAtTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_GetDividedBpmAtTime>`_",""
	"`TimeMap2_GetNextChangeTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_GetNextChangeTime>`_",""
	"`TimeMap2_QNToTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_QNToTime>`_","`Project.beats_to_time <reapy.core.html#reapy.core.Project.beats_to_time>`_"
	"`TimeMap2_beatsToTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_beatsToTime>`_",""
	"`TimeMap2_timeToBeats <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_timeToBeats>`_",""
	"`TimeMap2_timeToQN <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap2_timeToQN>`_","`Project.time_to_beats <reapy.core.html#reapy.core.Project.time_to_beats>`_"
	"`TimeMap_GetDividedBpmAtTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_GetDividedBpmAtTime>`_",""
	"`TimeMap_GetMeasureInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_GetMeasureInfo>`_",""
	"`TimeMap_GetMetronomePattern <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_GetMetronomePattern>`_",""
	"`TimeMap_GetTimeSigAtTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_GetTimeSigAtTime>`_",""
	"`TimeMap_QNToMeasures <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_QNToMeasures>`_",""
	"`TimeMap_QNToTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_QNToTime>`_","`Project.beats_to_time <reapy.core.html#reapy.core.Project.beats_to_time>`_"
	"`TimeMap_QNToTime_abs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_QNToTime_abs>`_",""
	"`TimeMap_curFrameRate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_curFrameRate>`_",""
	"`TimeMap_timeToQN <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_timeToQN>`_","`Project.time_to_beats <reapy.core.html#reapy.core.Project.time_to_beats>`_"
	"`TimeMap_timeToQN_abs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TimeMap_timeToQN_abs>`_",""
	"`TrackList_UpdateAllExternalSurfaces <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackList_UpdateAllExternalSurfaces>`_",""


Pitch Shifting
--------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`EnumPitchShiftModes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumPitchShiftModes>`_",""
	"`EnumPitchShiftSubModes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumPitchShiftSubModes>`_",""


Project Management
------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`CSurf_OnTempoChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnTempoChange>`_",""
	"`EnumProjExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumProjExtState>`_",""
	"`EnumProjects <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumProjects>`_","`Project <reapy.core.html#reapy.core.Project>`_"
	"`EnumRegionRenderMatrix <https://www.reaper.fm/sdk/reascript/reascripthelp.html#EnumRegionRenderMatrix>`_","`Region.rendered_tracks <reapy.core.html#reapy.core.Region.rendered_tracks>`_"
	"`GetCurrentProjectInLoadSave <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetCurrentProjectInLoadSave>`_",""
	"`GetFreeDiskSpaceForRecordPath <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetFreeDiskSpaceForRecordPath>`_",""
	"`GetProjExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjExtState>`_","`Project.get_ext_state <reapy.core.html#reapy.core.Project.get_ext_state>`_"
	"`GetProjectLength <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectLength>`_","`Project.length <reapy.core.html#reapy.core.Project.length>`_"
	"`GetProjectName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectName>`_","`Project.name <reapy.core.html#reapy.core.Project.name>`_"
	"`GetProjectPath <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectPath>`_","`Project.path <reapy.core.html#reapy.core.Project.path>`_"
	"`GetProjectPathEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectPathEx>`_","`Project.path <reapy.core.html#reapy.core.Project.path>`_"
	"`GetProjectStateChangeCount <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectStateChangeCount>`_",""
	"`GetProjectTimeOffset <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetProjectTimeOffset>`_",""
	"`GetSetProjectAuthor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetProjectAuthor>`_",""
	"`GetSetProjectGrid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetProjectGrid>`_",""
	"`GetSetProjectInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetProjectInfo>`_","`Project.get_info_value <reapy.core.html#reapy.core.Project.get_info_value>`_; `Project.set_info_value <reapy.core.html#reapy.core.Project.set_info_value>`_"
	"`GetSetProjectInfo_String <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetProjectInfo_String>`_","`Project.get_info_string <reapy.core.html#reapy.core.Project.get_info_string>`_; `Project.set_info_string <reapy.core.html#reapy.core.Project.set_info_string>`_"
	"`GetSetProjectNotes <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetProjectNotes>`_",""
	"`IsProjectDirty <https://www.reaper.fm/sdk/reascript/reascripthelp.html#IsProjectDirty>`_","`Project.is_dirty <reapy.core.html#reapy.core.Project.is_dirty>`_"
	"`Main_SaveProject <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Main_SaveProject>`_","`Project.save <reapy.core.html#reapy.core.Project.save>`_"
	"`Main_openProject <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Main_openProject>`_","`open_project <reapy.core.reaper.html#reapy.core.reaper.reaper.open_project>`_"
	"`MarkProjectDirty <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MarkProjectDirty>`_","`Project.mark_dirty <reapy.core.html#reapy.core.Project.mark_dirty>`_"
	"`SelectProjectInstance <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SelectProjectInstance>`_","`Project.make_current_project <reapy.core.html#reapy.core.Project.make_current_project>`_"
	"`SetCurrentBPM <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetCurrentBPM>`_","`Project.bpm <reapy.core.html#reapy.core.Project.bpm>`_"
	"`SetProjExtState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjExtState>`_","`Project.set_ext_state <reapy.core.html#reapy.core.Project.set_ext_state>`_"
	"`SetProjectGrid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetProjectGrid>`_",""
	"`SnapToGrid <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SnapToGrid>`_",""
	"`Undo_BeginBlock <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_BeginBlock>`_","`Project.begin_undo_block <reapy.core.html#reapy.core.Project.begin_undo_block>`_"
	"`Undo_BeginBlock2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_BeginBlock2>`_","`Project.begin_undo_block <reapy.core.html#reapy.core.Project.begin_undo_block>`_"
	"`Undo_CanRedo2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_CanRedo2>`_","`Project.can_redo <reapy.core.html#reapy.core.Project.can_redo>`_"
	"`Undo_CanUndo2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_CanUndo2>`_","`Project.can_undo <reapy.core.html#reapy.core.Project.can_undo>`_"
	"`Undo_DoRedo2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_DoRedo2>`_","`Project.redo <reapy.core.html#reapy.core.Project.redo>`_"
	"`Undo_DoUndo2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_DoUndo2>`_","`Project.undo <reapy.core.html#reapy.core.Project.undo>`_"
	"`Undo_EndBlock <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_EndBlock>`_","`Project.end_undo_block <reapy.core.html#reapy.core.Project.end_undo_block>`_; `undo_block <reapy.core.reaper.html#reapy.core.reaper.reaper.undo_block>`_"
	"`Undo_EndBlock2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_EndBlock2>`_","`Project.end_undo_block <reapy.core.html#reapy.core.Project.end_undo_block>`_"
	"`Undo_OnStateChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_OnStateChange>`_",""
	"`Undo_OnStateChange2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_OnStateChange2>`_",""
	"`Undo_OnStateChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_OnStateChangeEx>`_",""
	"`Undo_OnStateChangeEx2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_OnStateChangeEx2>`_",""
	"`Undo_OnStateChange_Item <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Undo_OnStateChange_Item>`_",""


Track Management
----------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`AnyTrackSolo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#AnyTrackSolo>`_","`Project.any_track_solo <reapy.core.html#reapy.core.Project.any_track_solo>`_"
	"`BypassFxAllTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#BypassFxAllTracks>`_","`Project.bypass_fx_on_all_tracks <reapy.core.html#reapy.core.Project.bypass_fx_on_all_tracks>`_"
	"`CSurf_GetTouchState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_GetTouchState>`_",""
	"`CSurf_NumTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_NumTracks>`_",""
	"`CSurf_OnFXChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnFXChange>`_",""
	"`CSurf_OnInputMonitorChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnInputMonitorChange>`_",""
	"`CSurf_OnInputMonitorChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnInputMonitorChangeEx>`_",""
	"`CSurf_OnMuteChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnMuteChange>`_",""
	"`CSurf_OnMuteChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnMuteChangeEx>`_",""
	"`CSurf_OnPanChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnPanChange>`_",""
	"`CSurf_OnPanChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnPanChangeEx>`_",""
	"`CSurf_OnRecArmChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRecArmChange>`_",""
	"`CSurf_OnRecArmChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRecArmChangeEx>`_",""
	"`CSurf_OnRecvPanChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRecvPanChange>`_",""
	"`CSurf_OnRecvVolumeChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRecvVolumeChange>`_",""
	"`CSurf_OnSelectedChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnSelectedChange>`_",""
	"`CSurf_OnSendPanChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnSendPanChange>`_",""
	"`CSurf_OnSendVolumeChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnSendVolumeChange>`_",""
	"`CSurf_OnSoloChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnSoloChange>`_",""
	"`CSurf_OnSoloChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnSoloChangeEx>`_",""
	"`CSurf_OnStop <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnStop>`_",""
	"`CSurf_OnTrackSelection <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnTrackSelection>`_",""
	"`CSurf_OnVolumeChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnVolumeChange>`_",""
	"`CSurf_OnVolumeChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnVolumeChangeEx>`_",""
	"`CSurf_OnWidthChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnWidthChange>`_",""
	"`CSurf_OnWidthChangeEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnWidthChangeEx>`_",""
	"`CSurf_ResetAllCachedVolPanStates <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_ResetAllCachedVolPanStates>`_",""
	"`CSurf_SetSurfaceMute <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfaceMute>`_",""
	"`CSurf_SetSurfacePan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfacePan>`_",""
	"`CSurf_SetSurfaceRecArm <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfaceRecArm>`_",""
	"`CSurf_SetSurfaceSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfaceSelected>`_",""
	"`CSurf_SetSurfaceSolo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfaceSolo>`_",""
	"`CSurf_SetSurfaceVolume <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetSurfaceVolume>`_",""
	"`CSurf_TrackFromID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_TrackFromID>`_",""
	"`CSurf_TrackToID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_TrackToID>`_",""
	"`ClearAllRecArmed <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ClearAllRecArmed>`_","`Project.disarm_rec_on_all_tracks <reapy.core.html#reapy.core.Project.disarm_rec_on_all_tracks>`_"
	"`CountSelectedTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountSelectedTracks>`_","`Project.n_selected_tracks <reapy.core.html#reapy.core.Project.n_selected_tracks>`_"
	"`CountSelectedTracks2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountSelectedTracks2>`_","`Project.n_selected_tracks <reapy.core.html#reapy.core.Project.n_selected_tracks>`_"
	"`CountTCPFXParms <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTCPFXParms>`_",""
	"`CountTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CountTracks>`_","`Project.n_tracks <reapy.core.html#reapy.core.Project.n_tracks>`_"
	"`CreateTrackSend <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CreateTrackSend>`_","`Track.add_send <reapy.core.html#reapy.core.Track.add_send>`_"
	"`DeleteTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DeleteTrack>`_","`Track.delete <reapy.core.html#reapy.core.Track.delete>`_"
	"`GetLastTouchedTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetLastTouchedTrack>`_","`get_last_touched_track <reapy.core.reaper.html#reapy.core.reaper.reaper.get_last_touched_track>`_"
	"`GetMasterMuteSoloFlags <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMasterMuteSoloFlags>`_","DEPRECATED"
	"`GetMasterTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMasterTrack>`_","`Project.master_track <reapy.core.html#reapy.core.Project.master_track>`_"
	"`GetMasterTrackVisibility <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMasterTrackVisibility>`_",""
	"`GetMediaItemTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItemTrack>`_","`Item.track <reapy.core.html#reapy.core.Item.track>`_"
	"`GetMediaItem_Track <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaItem_Track>`_","`Item.track <reapy.core.html#reapy.core.Item.track>`_"
	"`GetMediaTrackInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMediaTrackInfo_Value>`_","`Track.get_info_value <reapy.core.html#reapy.core.Track.get_info_value>`_"
	"`GetNumTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetNumTracks>`_","`Project.n_tracks <reapy.core.html#reapy.core.Project.n_tracks>`_"
	"`GetParentTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetParentTrack>`_","`Track.parent_track <reapy.core.html#reapy.core.Track.parent_track>`_"
	"`GetSelectedTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSelectedTrack>`_","`Project.selected_tracks <reapy.core.html#reapy.core.Project.selected_tracks>`_; `Project.get_selected_track <reapy.core.html#reapy.core.Project.get_selected_track>`_"
	"`GetSelectedTrack2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSelectedTrack2>`_","`Project.selected_tracks <reapy.core.html#reapy.core.Project.selected_tracks>`_; `Project.get_selected_track <reapy.core.html#reapy.core.Project.get_selected_track>`_"
	"`GetSetMediaTrackInfo_String <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetMediaTrackInfo_String>`_","`Track.get_info_string <reapy.core.html#reapy.core.Track.get_info_string>`_; `Track.set_info_string <reapy.core.html#reapy.core.Track.set_info_string>`_; `Track.GUID <reapy.core.html#reapy.core.Track.GUID>`_; `Track.icon <reapy.core.html#reapy.core.Track.icon>`_; `Track.name <reapy.core.html#reapy.core.Track.name>`_"
	"`GetSetTrackGroupMembership <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetTrackGroupMembership>`_",""
	"`GetSetTrackGroupMembershipHigh <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetTrackGroupMembershipHigh>`_",""
	"`GetSetTrackState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetTrackState>`_","DEPRECATED"
	"`GetSetTrackState2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetTrackState2>`_","DEPRECATED"
	"`GetTrack <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrack>`_","`Project.tracks <reapy.core.html#reapy.core.Project.tracks>`_"
	"`GetTrackColor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackColor>`_","`Track.color <reapy.core.html#reapy.core.Track.color>`_"
	"`GetTrackDepth <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackDepth>`_","`Track.depth <reapy.core.html#reapy.core.Track.depth>`_"
	"`GetTrackGUID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackGUID>`_","`Track.GUID <reapy.core.html#reapy.core.Track.GUID>`_"
	"`GetTrackName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackName>`_","`Track.name <reapy.core.html#reapy.core.Track.name>`_"
	"`GetTrackNumMediaItems <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackNumMediaItems>`_","`Track.n_items <reapy.core.html#reapy.core.Track.n_items>`_"
	"`GetTrackNumSends <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackNumSends>`_","`Track.n_sends <reapy.core.html#reapy.core.Track.n_sends>`_; `Track.n_receives <reapy.core.html#reapy.core.Track.n_receives>`_"
	"`GetTrackReceiveName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackReceiveName>`_",""
	"`GetTrackReceiveUIMute <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackReceiveUIMute>`_",""
	"`GetTrackReceiveUIVolPan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackReceiveUIVolPan>`_",""
	"`GetTrackSendInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackSendInfo_Value>`_","`Send <reapy.core.html#reapy.core.Send>`_"
	"`GetTrackSendName <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackSendName>`_",""
	"`GetTrackSendUIMute <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackSendUIMute>`_",""
	"`GetTrackSendUIVolPan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackSendUIVolPan>`_",""
	"`GetTrackState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackState>`_",""
	"`GetTrackStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackStateChunk>`_",""
	"`GetTrackUIMute <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackUIMute>`_",""
	"`GetTrackUIPan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackUIPan>`_",""
	"`GetTrackUIVolPan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTrackUIVolPan>`_",""
	"`InsertTrackAtIndex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#InsertTrackAtIndex>`_","`Project.add_track <reapy.core.html#reapy.core.Project.add_track>`_"
	"`IsTrackSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#IsTrackSelected>`_","`Track.is_selected <reapy.core.html#reapy.core.Track.is_selected>`_"
	"`IsTrackVisible <https://www.reaper.fm/sdk/reascript/reascripthelp.html#IsTrackVisible>`_",""
	"`RemoveTrackSend <https://www.reaper.fm/sdk/reascript/reascripthelp.html#RemoveTrackSend>`_","`Send.delete <reapy.core.html#reapy.core.Send.delete>`_"
	"`ReorderSelectedTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ReorderSelectedTracks>`_",""
	"`SetMasterTrackVisibility <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMasterTrackVisibility>`_",""
	"`SetMediaTrackInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMediaTrackInfo_Value>`_",""
	"`SetOnlyTrackSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetOnlyTrackSelected>`_","`Track.make_only_selected_track <reapy.core.html#reapy.core.Track.make_only_selected_track>`_"
	"`SetTrackColor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackColor>`_","`Track.color <reapy.core.html#reapy.core.Track.color>`_"
	"`SetTrackSelected <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackSelected>`_","`Track.is_selected <reapy.core.html#reapy.core.Track.is_selected>`_; `Track.select <reapy.core.html#reapy.core.Track.select>`_; `Track.unselect <reapy.core.html#reapy.core.Track.unselect>`_"
	"`SetTrackSendInfo_Value <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackSendInfo_Value>`_","`Send <reapy.core.html#reapy.core.Send>`_"
	"`SetTrackSendUIPan <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackSendUIPan>`_",""
	"`SetTrackSendUIVol <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackSendUIVol>`_",""
	"`SetTrackStateChunk <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetTrackStateChunk>`_",""
	"`SoloAllTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SoloAllTracks>`_","`Project.solo_all_tracks <reapy.core.html#reapy.core.Project.solo_all_tracks>`_; `Project.unsolo_all_tracks <reapy.core.html#reapy.core.Project.unsolo_all_tracks>`_"
	"`TrackFX_GetOpen <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_GetOpen>`_","`FX.is_ui_open <reapy.core.html#reapy.core.FX.is_ui_open>`_"
	"`TrackFX_SetOpen <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_SetOpen>`_","`FX.open_ui <reapy.core.html#reapy.core.FX.open_ui>`_; `FX.close_ui <reapy.core.html#reapy.core.FX.close_ui>`_"
	"`TrackFX_Show <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackFX_Show>`_","`FX.open_chain <reapy.core.html#reapy.core.FX.open_chain>`_; `FX.open_floating_window <reapy.core.html#reapy.core.FX.open_floating_window>`_; `FX.close_chain <reapy.core.html#reapy.core.FX.close_chain>`_; `FX.close_floating_window <reapy.core.html#reapy.core.FX.close_floating_window>`_"
	"`Track_GetPeakHoldDB <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Track_GetPeakHoldDB>`_",""
	"`Track_GetPeakInfo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Track_GetPeakInfo>`_",""


Transport Management
--------------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`CSurf_GoEnd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_GoEnd>`_",""
	"`CSurf_GoStart <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_GoStart>`_",""
	"`CSurf_OnFwd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnFwd>`_",""
	"`CSurf_OnPause <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnPause>`_",""
	"`CSurf_OnPlay <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnPlay>`_",""
	"`CSurf_OnPlayRateChange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnPlayRateChange>`_",""
	"`CSurf_OnRecord <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRecord>`_",""
	"`CSurf_OnRew <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRew>`_",""
	"`CSurf_OnRewFwd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_OnRewFwd>`_",""
	"`CSurf_ScrubAmt <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_ScrubAmt>`_",""
	"`CSurf_SetPlayState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetPlayState>`_",""
	"`CSurf_SetRepeatState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#CSurf_SetRepeatState>`_",""
	"`GetAllProjectPlayStates <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetAllProjectPlayStates>`_","`get_projects <reapy.core.reaper.html#reapy.core.reaper.reaper.get_projects>`_; `Project.play_state <reapy.core.html#reapy.core.Project.play_state>`_"
	"`GetCursorPosition <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetCursorPosition>`_","`Project.cursor_position <reapy.core.html#reapy.core.Project.cursor_position>`_"
	"`GetCursorPositionEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetCursorPositionEx>`_","`Project.cursor_position <reapy.core.html#reapy.core.Project.cursor_position>`_"
	"`GetPlayPosition <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayPosition>`_","`Project.play_position <reapy.core.html#reapy.core.Project.play_position>`_"
	"`GetPlayPosition2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayPosition2>`_","`Project.buffer_position <reapy.core.html#reapy.core.Project.buffer_position>`_"
	"`GetPlayPosition2Ex <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayPosition2Ex>`_","`Project.buffer_position <reapy.core.html#reapy.core.Project.buffer_position>`_"
	"`GetPlayPositionEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayPositionEx>`_","`Project.play_position <reapy.core.html#reapy.core.Project.play_position>`_"
	"`GetPlayState <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayState>`_","`Project.is_playing <reapy.core.html#reapy.core.Project.is_playing>`_; `Project.is_paused <reapy.core.html#reapy.core.Project.is_paused>`_; `Project.is_stopped <reapy.core.html#reapy.core.Project.is_stopped>`_; `Project.is_recording <reapy.core.html#reapy.core.Project.is_recording>`_"
	"`GetPlayStateEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetPlayStateEx>`_","`Project.play_state <reapy.core.html#reapy.core.Project.play_state>`_"
	"`GetSetRepeat <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetRepeat>`_","`TimeSelection.is_looping <reapy.core.html#reapy.core.TimeSelection.is_looping>`_; `TimeSelection.loop <reapy.core.html#reapy.core.TimeSelection.loop>`_; `TimeSelection.unloop <reapy.core.html#reapy.core.TimeSelection.unloop>`_"
	"`GetSetRepeatEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSetRepeatEx>`_","`TimeSelection.looping <reapy.core.html#reapy.core.TimeSelection.looping>`_; `TimeSelection.loop <reapy.core.html#reapy.core.TimeSelection.loop>`_; `TimeSelection.unloop <reapy.core.html#reapy.core.TimeSelection.unloop>`_"
	"`GetSet_LoopTimeRange <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSet_LoopTimeRange>`_","`Project.time_selection <reapy.core.html#reapy.core.Project.time_selection>`_"
	"`GetSet_LoopTimeRange2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetSet_LoopTimeRange2>`_","`Project.time_selection <reapy.core.html#reapy.core.Project.time_selection>`_"
	"`GoToMarker <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GoToMarker>`_",""
	"`GoToRegion <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GoToRegion>`_",""
	"`Loop_OnArrow <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Loop_OnArrow>`_","`TimeSelection.shift <reapy.core.html#reapy.core.TimeSelection.shift>`_"
	"`Master_GetPlayRate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Master_GetPlayRate>`_","`Project.play_rate <reapy.core.html#reapy.core.Project.play_rate>`_"
	"`Master_GetPlayRateAtTime <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Master_GetPlayRateAtTime>`_","`Project.get_play_rate <reapy.core.html#reapy.core.Project.get_play_rate>`_"
	"`Master_GetTempo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Master_GetTempo>`_","`Project.bpm <reapy.core.html#reapy.core.Project.bpm>`_"
	"`Master_NormalizePlayRate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Master_NormalizePlayRate>`_",""
	"`Master_NormalizeTempo <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Master_NormalizeTempo>`_",""
	"`MoveEditCursor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MoveEditCursor>`_",""
	"`MuteAllTracks <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MuteAllTracks>`_","`Project.mute_all_tracks <reapy.core.html#reapy.core.Project.mute_all_tracks>`_; `Project.unmute_all_tracks <reapy.core.html#reapy.core.Project.unmute_all_tracks>`_"
	"`OnPauseButton <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnPauseButton>`_","`Project.pause <reapy.core.html#reapy.core.Project.pause>`_"
	"`OnPauseButtonEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnPauseButtonEx>`_","`Project.pause <reapy.core.html#reapy.core.Project.pause>`_"
	"`OnPlayButton <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnPlayButton>`_","`Project.play <reapy.core.html#reapy.core.Project.play>`_"
	"`OnPlayButtonEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnPlayButtonEx>`_","`Project.play <reapy.core.html#reapy.core.Project.play>`_"
	"`OnStopButton <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnStopButton>`_","`Project.stop <reapy.core.html#reapy.core.Project.stop>`_"
	"`OnStopButtonEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OnStopButtonEx>`_","`Project.stop <reapy.core.html#reapy.core.Project.stop>`_"
	"`SetEditCurPos <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetEditCurPos>`_","`Project.cursor_position <reapy.core.html#reapy.core.Project.cursor_position>`_"
	"`SetEditCurPos2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetEditCurPos2>`_","`Project.cursor_position <reapy.core.html#reapy.core.Project.cursor_position>`_"


User Interface
--------------

.. csv-table::
	:header: "ReaScript API function", "reapy API function"

	"`DockIsChildOfDock <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockIsChildOfDock>`_",""
	"`DockWindowActivate <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowActivate>`_",""
	"`DockWindowAdd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowAdd>`_",""
	"`DockWindowAddEx <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowAddEx>`_",""
	"`DockWindowRefresh <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowRefresh>`_","`Window.refresh <reapy.core.html#reapy.core.Window.refresh>`_"
	"`DockWindowRefreshForHWND <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowRefreshForHWND>`_",""
	"`DockWindowRemove <https://www.reaper.fm/sdk/reascript/reascripthelp.html#DockWindowRemove>`_",""
	"`Dock_UpdateDockID <https://www.reaper.fm/sdk/reascript/reascripthelp.html#Dock_UpdateDockID>`_",""
	"`GR_SelectColor <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GR_SelectColor>`_",""
	"`GSC_mainwnd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GSC_mainwnd>`_",""
	"`GetConfigWantsDock <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetConfigWantsDock>`_",""
	"`GetLastColorThemeFile <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetLastColorThemeFile>`_","`ui.get_color_theme <reapy.core.reaper.html#reapy.core.reaper.ui.get_color_theme>`_"
	"`GetMainHwnd <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMainHwnd>`_","`get_main_window <reapy.core.reaper.html#reapy.core.reaper.reaper.get_main_window>`_"
	"`GetMixerScroll <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMixerScroll>`_","`ui.get_leftmost_track_in_mixer <reapy.core.reaper.html#reapy.core.reaper.ui.get_leftmost_track_in_mixer>`_"
	"`GetMouseModifier <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMouseModifier>`_",""
	"`GetMousePosition <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetMousePosition>`_",""
	"`GetTooltipWindow <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetTooltipWindow>`_","`ToolTip <reapy.core.html#reapy.core.ToolTip>`_"
	"`GetUserFileNameForRead <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetUserFileNameForRead>`_","`browse_for_file <reapy.core.reaper.html#reapy.core.reaper.reaper.browse_for_file>`_"
	"`GetUserInputs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#GetUserInputs>`_","`get_user_inputs <reapy.core.reaper.html#reapy.core.reaper.reaper.get_user_inputs>`_"
	"`LICE_ClipLine <https://www.reaper.fm/sdk/reascript/reascripthelp.html#LICE_ClipLine>`_",""
	"`MB <https://www.reaper.fm/sdk/reascript/reascripthelp.html#MB>`_","`reapy.show_message_box <reapy.core.reaper.html#reapy.core.reaper.reapy.show_message_box>`_"
	"`OpenColorThemeFile <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OpenColorThemeFile>`_","`ui.set_color_theme <reapy.core.reaper.html#reapy.core.reaper.ui.set_color_theme>`_"
	"`OpenMediaExplorer <https://www.reaper.fm/sdk/reascript/reascripthelp.html#OpenMediaExplorer>`_",""
	"`PreventUIRefresh <https://www.reaper.fm/sdk/reascript/reascripthelp.html#PreventUIRefresh>`_","`prevent_ui_refresh <reapy.core.reaper.html#reapy.core.reaper.reaper.prevent_ui_refresh>`_"
	"`RefreshToolbar <https://www.reaper.fm/sdk/reascript/reascripthelp.html#RefreshToolbar>`_",""
	"`RefreshToolbar2 <https://www.reaper.fm/sdk/reascript/reascripthelp.html#RefreshToolbar2>`_",""
	"`SetMixerScroll <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMixerScroll>`_","`ui.set_leftmost_track_in_mixer <reapy.core.reaper.html#reapy.core.reaper.ui.set_leftmost_track_in_mixer>`_"
	"`SetMouseModifier <https://www.reaper.fm/sdk/reascript/reascripthelp.html#SetMouseModifier>`_",""
	"`ShowMessageBox <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ShowMessageBox>`_","`show_message_box <reapy.core.reaper.html#reapy.core.reaper.reaper.show_message_box>`_"
	"`ShowPopupMenu <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ShowPopupMenu>`_",""
	"`TrackCtl_SetToolTip <https://www.reaper.fm/sdk/reascript/reascripthelp.html#TrackCtl_SetToolTip>`_","`ToolTip <reapy.core.html#reapy.core.ToolTip>`_"
	"`ViewPrefs <https://www.reaper.fm/sdk/reascript/reascripthelp.html#ViewPrefs>`_","`view_prefs <reapy.core.reaper.html#reapy.core.reaper.reaper.view_prefs>`_"
	"`my_getViewport <https://www.reaper.fm/sdk/reascript/reascripthelp.html#my_getViewport>`_",""


